@@ -75,14 +75,11 @@ class GZDoomContext(SuperContext):
             self.tracker_task = asyncio.create_task(self._tracker_loop())
         else:
             self.tracker_task = None
-        print("Starting server loop")
-        self.server_task = asyncio.create_task(server_loop(self), name="ServerLoop")
         print("All tasks started.")
 
     async def send_check(self, id: int):
-        await self.send_msgs([
-            {"cmd": 'LocationChecks', "locations": [id]}
-            ])
+        self.locations_checked |= {id}
+        await self.check_locations(self.locations_checked)
 
     async def send_chat(self, message: str):
         await self.send_msgs([
@@ -111,7 +108,7 @@ class GZDoomContext(SuperContext):
         await self.get_username()
         await self.send_connect()
 
-    async def on_xon(self, slot: str, seed: str):
+    async def on_xon(self, slot: str, seed: str, server: str):
         self.slot_name = slot
         self.seed_name = seed
         self.last_items = {}  # force a re-send of all items
@@ -120,6 +117,10 @@ class GZDoomContext(SuperContext):
         self.last_hints = {}
         self.found_gzdoom.set()
         self.ipc.send_text("Archipelago<->GZDoom connection established.")
+        if server:
+            await self.connect(server)
+            # TODO: send a message to the game when the connection to the host is
+            # opened or closed.
 
     async def on_xoff(self):
         self.username = None
@@ -217,16 +218,20 @@ class GZDoomContext(SuperContext):
         self.last_tracked_ool = set()
         while not self.exit_event.is_set():
             await self.watcher_event.wait()
+            if self.tracker_core.get_current_world() is None:
+                continue
+
             self.watcher_event.clear()
             new_ool = set(self.glitched_locations) - self.last_tracked_ool
             new_il = set(self.locations_available) - self.last_tracked
 
             # print("tracker_loop IL: ", new_il, self.last_tracked)
             # print("tracker_loop OOL:", new_ool, self.last_tracked_ool)
-            for id in new_ool:
-                self.ipc.send_track(id, "OOL")
-            for id in new_il:
-                self.ipc.send_track(id, "IL")
+            id_map = self.tracker_core.get_current_world().location_name_to_id
+            for name in new_ool:
+                self.ipc.send_track(id_map[name], "OOL")
+            for name in new_il:
+                self.ipc.send_track(id_map[name], "IL")
             self.ipc.flush()
             # Over the course of the game, locations may be added to OOL and then
             # removed from it and added to IL. These locations will gradually
@@ -261,13 +266,12 @@ def launch(server_address: str = None, password: str = None, ready_callback=None
     """
     Launch the client
     """
-    import logging
-    logging.getLogger("GZDoomClient")
+    Utils.init_logging("GZDoomClient")
 
     async def main():
         # Initialize the gzDoom IPC structures on disk
         # TODO: do we want to support multiple running instances as the same user?
-        gzd_dir = os.path.join(Utils.home_path(), "gzdoom")
+        gzd_dir = os.path.join(Utils.local_path("data"), "gzdoom")
         ipc_dir = os.path.join(gzd_dir, "ipc")
         os.makedirs(ipc_dir, exist_ok=True) # communication with gzdoom
         os.makedirs(os.path.join(gzd_dir, "logic"), exist_ok=True) # in-dev logic files
